==> iTop-3.1.0-2-11973.zip: web/datamodels/2.x/itop-portal/dictionaries/en.dict.itop-portal.php <==
<?php
// Copyright (C) 2010-2023 Combodo SARL
//
//   This file is part of iTop.
//
//   iTop is free software; you can redistribute it and/or modify
//   it under the terms of the GNU Affero General Public License as published by
//   the Free Software Foundation, either version 3 of the License, or
//   (at your option) any later version.
//
//   iTop is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU Affero General Public License for more details.
//
//   You should have received a copy of the GNU Affero General Public License
//   along with iTop. If not, see <http://www.gnu.org/licenses/>
/**
 * @author      Benjamin Planque <benjamin.planque@combodo.com>
 * @copyright   Copyright (C) 2010-2023 Combodo SARL
 * @license     http://opensource.org/licenses/AGPL-3.0
 */

//////////////////////////////////////////////////////////////////////
// Note: The classes have been grouped by categories: bizmodel
//////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////
// Classes in 'bizmodel'
//////////////////////////////////////////////////////////////////////
//

Dict::Add('EN US', 'English', 'English', array(
	'portal:itop-portal' => 'Standard portal', // This is the portal name that will be displayed in portal dispatcher (eg. URL in menus)
	'Page:DefaultTitle' => '%1$s - User portal',
	'Brick:Portal:UserProfile:Title' => 'My profile',
	'Brick:Portal:NewRequest:Title' => 'New request',
	'Brick:Portal:NewRequest:Title+' => '<p>Need help?</p><p>Pick from the services catalog and submit your request to our support teams.</p>',
	'Brick:Portal:OngoingRequests:Title' => 'Ongoing requests',
	'Brick:Portal:OngoingRequests:Title+' => '<p>Follow up with your ongoing requests.</p><p>Check the progress, add comments, attach documents, acknowledge the solution.</p>',
	'Brick:Portal:OngoingRequests:Tab:OnGoing' => 'Open',
	'Brick:Portal:OngoingRequests:Tab:Resolved' => 'Resolved',
	'Brick:Portal:ClosedRequests:Title' => 'Closed requests',
));

==> iTop-3.2.1-1-16749.zip: web/datamodels/2.x/itop-portal/dictionaries/en.dict.itop-portal.php <==
<?php
// Copyright (C) 2010-2024 Combodo SAS
//
//   This file is part of iTop.
//
//   iTop is free software; you can redistribute it and/or modify
//   it under the terms of the GNU Affero General Public License as published by
//   the Free Software Foundation, either version 3 of the License, or
//   (at your option) any later version.
//
//   iTop is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU Affero General Public License for more details.
//
//   You should have received a copy of the GNU Affero General Public License
//   along with iTop. If not, see <http://www.gnu.org/licenses/>
/**
 * @author      Benjamin Planque <benjamin.planque@combodo.com>
 * @copyright   Copyright (C) 2010-2024 Combodo SAS
 * @license     http://opensource.org/licenses/AGPL-3.0
 */

//////////////////////////////////////////////////////////////////////
// Note: The classes have been grouped by categories: bizmodel
//////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////
// Classes in 'bizmodel'
//////////////////////////////////////////////////////////////////////
//

Dict::Add('EN US', 'English', 'English', array(
	'portal:itop-portal' => 'Standard portal', // This is the portal name that will be displayed in portal dispatcher (eg. URL in menus)
	'Page:DefaultTitle' => '%1$s - User portal',
	'Brick:Portal:UserProfile:Title' => 'My profile',
	'Brick:Portal:NewRequest:Title' => 'New request',
	'Brick:Portal:NewRequest:Title+' => '<p>Need help?</p><p>Pick from the services catalog and submit your request to our support teams.</p>',
	'Brick:Portal:OngoingRequests:Title' => 'Ongoing requests',
	'Brick:Portal:OngoingRequests:Title+' => '<p>Follow up with your ongoing requests.</p><p>Check the progress, add comments, attach documents, acknowledge the solution.</p>',
	'Brick:Portal:OngoingRequests:Tab:OnGoing' => 'Open',
	'Brick:Portal:OngoingRequests:Tab:Resolved' => 'Resolved',
	'Brick:Portal:ClosedRequests:Title' => 'Closed requests',
	'Brick:Portal:ListAllRequests:Title' => 'All requests',
	'Brick:Portal:ListAllRequests:Title+' => '<p>View all requests regardless of their status.</p>',
	'Brick:Portal:ListAllRequests:Tab' => 'On-going and closed',
	'Brick:Portal:SearchInAllRequests:Title' => 'Search in all requests',
	'Brick:Portal:SearchInAllRequests:Title+' => '<p>Regardless of their status.</p>',
));
